# `calc9000`

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/e47ea24859a6423b8f46e472ab27cb6d)](https://www.codacy.com/manual/weakit/calc9000?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=weakit/calc9000&amp;utm_campaign=Badge_Grade) 

A poorly written frontend (?) of sorts, for sympy, horribly put together.

Best to not touch it.
